# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section         free
%define namedversion    2.0

Name:           guiceyfruit
Version:        2.0
Release:        1%{?dist}
Epoch:          0
Summary:        Guiceyfruit Guice2 utilities
License:        Apache Software License 2.0
Group:          Development/Libraries/Java
Url:            http://guiceyfruit.googlecode.com/
Source0:        http://guiceyfruit.googlecode.com/svn/repo/releases/org/guiceyfruit/guiceyfruit/2.0/guiceyfruit-2.0-src.tar.gz

Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml

Patch0:         guiceyfruit-Injectors.patch
Patch1:         guiceyfruit-CloseableScope.patch
Patch2:         guiceyfruit-InjectorsTest.patch
Patch3:         guiceyfruit-spring-converter-ModuleGenerator.patch
Patch4:         guiceyfruit-pom.patch
Patch5:         guiceyfruit-core-pom.patch
Patch6:         guiceyfruit-guiceyfruit-pom.patch

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7
BuildRequires:  apache-commons-parent >= 0:12
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-assembly
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-dependency
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  aries-testsupport
BuildRequires:  geronimo-genesis
BuildRequires:  ops4j-pax-exam
BuildRequires:  oss-parent
BuildRequires:  servicemix-depends-maven-plugin
BuildRequires:  testng

BuildRequires:  google-guice

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5
Requires:       java >= 0:1.6.0
Requires:       google-guice
%if ! %{gcj_support}
BuildArch:      noarch
%endif
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if %{gcj_support}
BuildRequires:          java-gcj-compat-devel
Requires(post):         java-gcj-compat
Requires(postun):       java-gcj-compat
%endif

%description
GuiceyFruit provides a number of utilities on top of the 
Guice 2.x to help developers work with standard Annotations 
for injection and lifecycles from JSR 250, Spring, EJB3 and 
JPA as well as supporting Maven and improved Testing
GuiceyFruit includes these features
* Support for @Resource injection for JSR 250 / EJB3 and 
  @PersistenceContext injection from JPA (see Annotations)
* Support for Spring annotations and lifecycle interfaces
* Lifecycle support such as for @PostConstruct, @PreDestroy 
  from JSR 250 & EJB3
* a Guice based JNDI provider to help you make that J2EE 
  code all Guicey underneath! :)
* Guicey Testing for easy injection of resources into your 
  test classes in JUnit3, JUnit4 or TestNG with flexible 
  mapping to the Guice Modules for your test cases
* a Spring XML to Java code converter to help you turn that 
  Spring XML into Java code
* Maven fully mavenized for easy use from Maven builds 


%package devel
Summary:        Sources for %{name}
Group:          Development/Documentation

%description devel
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q 

%patch0 -b .sav0
%patch1 -b .sav1
%patch2 -b .sav2
%patch3 -b .sav3
%patch4 -b .sav4
%patch5 -b .sav5
%patch6 -b .sav6

cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" settings.xml

mkdir external_repo
ln -s %{_javadir} external_repo/JPP


%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}

export MAVEN_SETTINGS=$(pwd)/settings.xml

cd src

%{_bindir}/mvn-jpp \
        -e \
        -s ${MAVEN_SETTINGS} \
        -Dmaven.test.skip=true \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=${MAVEN_REPO_LOCAL} \
        install 

%{_bindir}/mvn-jpp \
        -e \
        -s ${MAVEN_SETTINGS} \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=${MAVEN_REPO_LOCAL} \
        -Daggregate=true \
        javadoc:javadoc

%install
rm -rf $RPM_BUILD_ROOT
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/%{name}
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/%{name}-sources

install -m 644 src/guiceyfruit/bundle/target/%{name}-bundle-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/bundle-%{version}.jar
#install -m 644 src/guiceyfruit/bundle/target/%{name}-bundle-%{version}-sources.jar \
#               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/bundle-%{version}.jar
install -m 644 src/guiceyfruit-core/target/%{name}-core-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/core-%{version}.jar
install -m 644 src/guiceyfruit-core/target/%{name}-core-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/core-%{version}.jar
install -m 644 src/guiceyfruit-jpa/target/%{name}-jpa-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/jpa-%{version}.jar
install -m 644 src/guiceyfruit-jpa/target/%{name}-jpa-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/jpa-%{version}.jar
install -m 644 src/guiceyfruit-junit3/target/%{name}-junit3-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/junit3-%{version}.jar
install -m 644 src/guiceyfruit-junit3/target/%{name}-junit3-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/junit3-%{version}.jar
install -m 644 src/guiceyfruit-junit4/target/%{name}-junit4-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/junit4-%{version}.jar
install -m 644 src/guiceyfruit-junit4/target/%{name}-junit4-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/junit4-%{version}.jar
install -m 644 src/guiceyfruit-osgi-test/target/%{name}-osgi-test-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/osgi-test-%{version}.jar
#install -m 644 src/guiceyfruit-osgi-test/target/%{name}-osgi-test-%{version}-sources.jar \
#               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/osgi-test-%{version}.jar
install -m 644 src/guiceyfruit-spring-converter/target/%{name}-spring-converter-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/spring-converter-%{version}.jar
install -m 644 src/guiceyfruit-spring-converter/target/%{name}-spring-converter-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/spring-converter-%{version}.jar
install -m 644 src/guiceyfruit-spring/target/%{name}-spring-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/spring-%{version}.jar
install -m 644 src/guiceyfruit-spring/target/%{name}-spring-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/spring-%{version}.jar
install -m 644 src/guiceyfruit-testng/target/%{name}-testng-%{version}.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}/testng-%{version}.jar
install -m 644 src/guiceyfruit-testng/target/%{name}-testng-%{version}-sources.jar \
               $RPM_BUILD_ROOT%{_javadir}/%{name}-sources/testng-%{version}.jar

(cd $RPM_BUILD_ROOT%{_javadir}/%{name} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir}/%{name}-sources && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

# Install pom files
install -dm 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -m 644 src/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-parent.pom
%add_to_maven_depmap org.guiceyfruit parent %{version} JPP/%{name} parent
install -m 644 src/guiceyfruit/bundle/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-bundle.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-bundle %{version} JPP/%{name} bundle
install -m 644 src/guiceyfruit-core/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-core.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-core %{version} JPP/%{name} core
install -m 644 src/guiceyfruit-jpa/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jpa.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-jpa %{version} JPP/%{name} jpa
install -m 644 src/guiceyfruit-junit3/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-junit3.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-junit3 %{version} JPP/%{name} junit3
install -m 644 src/guiceyfruit-junit4/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-junit4.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-junit4 %{version} JPP/%{name} junit4
install -m 644 src/guiceyfruit-osgi-test/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-osgi-test.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-osgi-test %{version} JPP/%{name} osgi-test
install -m 644 src/guiceyfruit/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-guiceyfruit.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit %{version} JPP/%{name} guiceyfruit
install -m 644 src/guiceyfruit-spring-converter/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-spring-converter.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-spring-converter %{version} JPP/%{name} spring-converter
install -m 644 src/guiceyfruit-spring/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-spring.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-spring %{version} JPP/%{name} spring
install -m 644 src/guiceyfruit-testng/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-testng.pom
%add_to_maven_depmap org.guiceyfruit guiceyfruit-testng %{version} JPP/%{name} testng

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr src/target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(-,root,root)
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/*.jar
%if %{gcj_support}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%files devel
%defattr(-,root,root)
%dir %{_javadir}/%{name}-sources
%{_javadir}/%{name}-sources/*.jar

%files javadoc
%defattr(-,root,root)
%doc %{_javadocdir}/*

%changelog
* Sat Oct 01 2011 Ralph Apel <r.apel@r-apel.de> - 0:2.0-1
- first release

